@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2011-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
 from collections import OrderedDict
@@ -365,7 +365,8 @@ class CalendarView(DayNavigator):
 
     @classmethod
     def get_default_action(cls):
-        return dd.ShowDetail(cls.detail_layout)
+        return cls.detail_action
+        # return dd.ShowDetail(cls.detail_layout)
 
     @dd.htmlbox()
     def navigation_panel(cls, obj, ar):
@@ -488,7 +489,8 @@ class DaySlave(AbstractTable):
 
     abstract = True
     editable = False
-    hide_top_toolbar = True # no selections no toolbar
+    # hide_top_toolbar = True # no selections no toolbar
+    hide_navigator = True # no selections no toolbar
     preview_limit = 0       # no paginator & all rows.
     use_detail_params_value = True # Get parameter values from detail view.
     master = 'calview.Day'
