@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2016-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
 from lino.api import dd, rt, _
@@ -11,7 +11,7 @@ class StartInvoicing(StartPlan):
     label = _("Create invoices")
     icon_name = 'basket'
 
-    def get_plan_model(self):
+    def get_plan_model(self, ar):
         return rt.models.invoicing.Plan
 
 
