@@ -1,7 +1,17 @@
-# Copyright 2015-2017 Rumma & Ko Ltd
+# Copyright 2015-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""An extension of :mod:`lino.modlib.users` which adds functionality
-for managing online registration.
+"""
+
+Deprecated. :term:`online registration` this is now implemented in the standard
+:mod:`lino.modlib.users`.
+
+An extension of :mod:`lino.modlib.users` that makes User inherit from Person
+(Multi-table inheritance).
+
+The main purpose was to automatically have a :term:`partner` for every
+:term:`site user`.
+
+
 
 .. autosummary::
    :toctree:
