@@ -88,7 +88,7 @@ class NewUsers(Users):
     column_names = 'created first_name last_name username user_type workflow_buttons *'
     order_by = ['created']
 
-    send_welcome_email = SendWelcomeMail()
+    # send_welcome_email = SendWelcomeMail()
 
     @classmethod
     def param_defaults(self, ar, **kw):
