@@ -1,48 +1,48 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2019 Rumma 6 Ko Ltd
-# License: BSD (see file COPYING for details)
-
+# Copyright 2008-2021 Rumma 6 Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
-from django.utils.translation import gettext_lazy as _
 
-from lino.api import dd, rt
-from lino import mixins
+from lino.api import dd, rt, _
 from lino.mixins import Sequenced
+from lino.mixins import Hierarchical
 from lino.mixins.duplicable import Duplicable
+from lino.utils.mldbc.mixins import BabelNamed
+from lino.modlib.memo.mixins import BabelPreviewable
 
 from lino_xl.lib.vat.choicelists import VatClasses
 
 from .choicelists import DeliveryUnits, ProductTypes, PriceFactors
 from .roles import ProductsUser, ProductsStaff
 
-# vat = dd.resolve_app('vat')
 
-
-class ProductCat(mixins.BabelNamed):
+class Category(BabelNamed, BabelPreviewable, Hierarchical):
 
     class Meta:
         app_label = 'products'
         verbose_name = _("Product Category")
         verbose_name_plural = _("Product Categories")
-        abstract = dd.is_abstract_model(__name__, 'ProductCat')
+        abstract = dd.is_abstract_model(__name__, 'Category')
 
     product_type = ProductTypes.field(default='default')
-    description = models.TextField(blank=True)
+
+dd.update_field(Category, 'body', verbose_name=_("Long description"))
 
 
-class ProductCats(dd.Table):
-    model = 'products.ProductCat'
+class Categories(dd.Table):
+    model = 'products.Category'
     required_roles = dd.login_required(ProductsStaff)
     order_by = ["id"]
+    column_names = "id parent name product_type *"
     detail_layout = """
     id name
-    description
+    body
     ProductsByCategory
     """
 
 
-class Product(mixins.BabelNamed, Duplicable):
+class Product(BabelNamed, BabelPreviewable, Duplicable):
 
     class Meta:
         app_label = 'products'
@@ -50,20 +50,22 @@ class Product(mixins.BabelNamed, Duplicable):
         verbose_name_plural = _("Products")
         abstract = dd.is_abstract_model(__name__, 'Product')
 
-    description = dd.BabelTextField(
-        verbose_name=_("Long description"),
+    category = dd.ForeignKey(
+        Category, verbose_name=_("Category"),
         blank=True, null=True)
-    cat = dd.ForeignKey(
-        ProductCat, verbose_name=_("Category"),
-        blank=True, null=True)
-
     delivery_unit = DeliveryUnits.field(default='piece')
     product_type = ProductTypes.field()
     vat_class = VatClasses.field(blank=True)
 
+    @classmethod
+    def get_simple_parameters(cls):
+        for p in super(Product, cls).get_simple_parameters():
+            yield p
+        yield "category"
+
     @dd.chooser()
-    def cat_choices(self, product_type):
-        qs = rt.models.products.ProductCats.request().data_iterator
+    def category_choices(self, product_type):
+        qs = rt.models.products.Categories.request().data_iterator
         if product_type is not None:
             qs = qs.filter(product_type=product_type)
         return qs
@@ -110,34 +112,48 @@ class Product(mixins.BabelNamed, Duplicable):
     def full_clean(self):
         # print("20191210", self.name, self.vat_class)
         if self.product_type is None:
-            if self.cat_id:
-                self.product_type = self.cat.product_type or ProductTypes.default
+            if self.category_id:
+                self.product_type = self.category.product_type or ProductTypes.default
             else:
                 self.product_type = ProductTypes.default
         super(Product, self).full_clean()
 
 
+dd.update_field(Product, 'body', verbose_name=_("Long description"))
+
 class ProductDetail(dd.DetailLayout):
 
     main = """
-    id cat #sales_price vat_class delivery_unit
+    id category #sales_price vat_class delivery_unit
     name
-    description
+    body
     """
 
 
-class Products(dd.Table):
-    _product_type = None
+class BaseProducts(dd.Table):
+    abstract = True
     required_roles = dd.login_required(ProductsUser)
     model = 'products.Product'
     order_by = ["name"]
-    column_names = "id name cat vat_class *"
+    column_names = "id name category vat_class *"
+
+    detail_layout = "products.ProductDetail"
 
     insert_layout = """
-    cat
+    category
     name
     """
-    detail_layout = "products.ProductDetail"
+
+    card_layout = """name category
+    body_short_preview
+    workflow_buttons
+    """
+
+    list_layout = """name category workflow_buttons"""
+
+
+class Products(BaseProducts):
+    _product_type = None
 
     @classmethod
     def get_actor_label(cls):
@@ -155,8 +171,8 @@ class Products(dd.Table):
         return super(Products, cls).get_queryset(ar, **filter)
 
 
-class ProductsByCategory(Products):
-    master_key = 'cat'
+class ProductsByCategory(BaseProducts):
+    master_key = 'category'
 
 
 class PriceRule(Sequenced):
@@ -191,3 +207,17 @@ def inject_pricefactor_fields(sender, **kw):
         dd.inject_field(
             'contacts.Partner', pf.field_name,
             pf.field_cls.field(blank=True))
+
+
+@dd.receiver(dd.post_startup)
+def setup_memo_commands(sender=None, **kwargs):
+    # See :doc:`/specs/memo`
+
+    if not sender.is_installed('memo'):
+        return
+
+    Product = sender.models.products.Product
+    mp = sender.plugins.memo.parser
+
+    mp.register_django_model(
+        'product', Product, title=lambda obj: str(obj.name))
