@@ -183,8 +183,10 @@ class TicketType(mixins.BabelNamed):
 class Site(Referrable, ContactRelated, Starrable, DateRange):
     class Meta:
         app_label = 'tickets'
-        verbose_name = pgettext("Ticketing", "Site")
-        verbose_name_plural = pgettext("Ticketing", "Sites")
+        # verbose_name = pgettext("Ticketing", "Site")
+        # verbose_name_plural = pgettext("Ticketing", "Sites")
+        verbose_name = _("Project")
+        verbose_name_plural = _("Projects")
         abstract = dd.is_abstract_model(__name__, 'Site')
 
     ref_max_length = 20
@@ -573,7 +575,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         elif not user.user_type.has_required_roles([TicketsStaff]):
             qs = qs.filter(
                 Q(site__group__members__user__id=user.pk) |
-                Q(user=user) | Q(end_user=user)|
+                Q(user=user) | # Q(end_user=user)|
                 Q(assigned_to=user)|
                 Q(private=False, site__private=False)).distinct()
         return qs
@@ -590,7 +592,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         if user.user_type.has_required_roles([PrivateCommentsReader]):
             return None
         flt = Q(ticket__site__group__members__user__id=user.pk)
-        flt |= Q(ticket__user=user) | Q(ticket__end_user=user)
+        flt |= Q(ticket__user=user) # | Q(ticket__end_user=user)
         flt |= Q(ticket__assigned_to=user)
         flt |= Q(user=user) | Q(private=False)
         return flt
@@ -628,16 +630,17 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
             self.duplicate_of = None
         # print "20150523b on_create", self.reporter
         if not self.site_id:
-            person = self.end_user or self.user.get_person()
-            qs = rt.models.tickets.Site.objects.filter(contact_person=person)
-            qs = qs.filter(state=SiteStates.active)
-            qs = qs.filter(Q(end_date__isnull=True) | Q(end_date__lte=dd.today()))
-            qs = qs.order_by('-id')
-            # qs = rt.models.tickets.Subscription.objects.filter(
-            #     user=user, primary=True)
-            if qs.count():
-                # self.site = qs[0].site
-                self.site = qs.first()
+            person = self.end_user or self.user.person
+            if person is not None:
+                qs = rt.models.tickets.Site.objects.filter(contact_person=person)
+                qs = qs.filter(state=SiteStates.active)
+                qs = qs.filter(Q(end_date__isnull=True) | Q(end_date__lte=dd.today()))
+                qs = qs.order_by('-id')
+                # qs = rt.models.tickets.Subscription.objects.filter(
+                #     user=user, primary=True)
+                if qs.count():
+                    # self.site = qs[0].site
+                    self.site = qs.first()
         super(Ticket, self).full_clean()
 
     def get_change_owner(self):
