@@ -6,10 +6,10 @@
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='21.4.0',
+    version='21.4.2',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
-    description="Lino Extensions Library",
+    description="The Lino Extensions Library",
     license_files=['COPYING'],
     author='Rumma & Ko Ltd',
     author_email='info@saffre-rumma.net',
